@@ -1,6 +1,7 @@
 import requests
 import json
 import os
+from PIL import Image
 from progressbar import progressbar
 
 def download_from_google_images(keywords : str, limit : int, directory : str):
@@ -24,7 +25,6 @@ def download_from_google_images(keywords : str, limit : int, directory : str):
         download_image(el["url"], directory)
 
 def download_image(image_url, directory):
-    print(image_url)
     filename = image_url.split("/")[-1].split("?")[0]
     path = f'{directory}/{filename}'
 
@@ -42,5 +42,12 @@ def download_image(image_url, directory):
     with open(path, 'wb') as handler:
         handler.write(img_data)
 
+    # verify it is not corrupted
+    try:
+        img = Image.open(path) # open the image file
+        img.verify() # verify that it is, in fact an image
+    except (IOError, SyntaxError) as e:
+        print('Bad file:', filename) # print out the names of corrupt files
+
 if __name__ == "__main__":
-    download_from_google_images("bmw", 800, "test_bmw/")
\ No newline at end of file
+    download_from_google_images("courgettes", 50, "test_bmw/")
\ No newline at end of file
